@@ -2,8 +2,8 @@
 *     xfpt - Simple ASCII->Docbook processor     *
 *************************************************/
 
-/* Copyright (c) University of Cambridge, 2020 */
-/* Written by Philip Hazel. */
+/* Copyright (c) University of Cambridge, 2023 */
+/* Written by Philip Hazel, started in 2006 */
 
 /* This module contains code for processing a line that starts with a dot. */
 
@@ -109,7 +109,7 @@ do_arg(uschar *p)
 {
 BOOL mustexist = TRUE;
 argstr *arg;
-int i, argn;
+int argn;
 
 if (from_type[from_type_ptr] != FROM_MACRO) { error(15, US".arg"); return; }
 
@@ -123,7 +123,7 @@ argn = readnumber(p);
 if (argn < 0) return;
 
 arg = macrocurrent->args;
-for (i = 1; arg != NULL && i < argn; i++) arg = arg->next;
+for (int i = 1; arg != NULL && i < argn; i++) arg = arg->next;
 
 if (mustexist != (arg != NULL && arg->string[0] != 0))
   skipto(US".arg", US".endarg");
@@ -146,15 +146,19 @@ static void
 do_eacharg(uschar *p)
 {
 argstr *arg;
-int argn, i;
+int argn;
 
-if (from_type[from_type_ptr] != FROM_MACRO) { error(15, US".eacharg"); return; }
+if (from_type[from_type_ptr] != FROM_MACRO)
+  {
+  error(15, US".eacharg");
+  return;
+  }
 
 argn = (*p == 0)? 1 : readnumber(p);
 if (argn < 0) return;
 
 arg = macrocurrent->args;
-for (i = 1; arg != NULL && i < argn; i++) arg = arg->next;
+for (int i = 1; arg != NULL && i < argn; i++) arg = arg->next;
 
 /* If we did not find the starting argument, skip. Otherwise, set up the
 substitution for relative arguments, and remember where to come back to. */
@@ -191,7 +195,7 @@ do_echo(uschar *p)
 *************************************************/
 
 /* We only hit this as a stand-alone directive when the argument exists and the
-previous lines have been obeyed. There is nothing to do.
+previous lines have been obeyed. There is nothing to do, but check for errors.
 
 Argument:   the rest of the line
 Returns:    nothing
@@ -200,8 +204,8 @@ Returns:    nothing
 static void
 do_endarg(uschar *p)
 {
-if (from_type[from_type_ptr] != FROM_MACRO) { error(15, US".endarg"); return; }
-if (*p != 0) error(19, ".endarg", p, 8, spaces, Ustrlen(p), circumflexes);
+if (from_type[from_type_ptr] != FROM_MACRO) error(15, US".endarg");
+else if (*p != 0) error(19, ".endarg", p, 8, spaces, Ustrlen(p), circumflexes);
 }
 
 
@@ -223,7 +227,11 @@ do_endeach(uschar *p)
 {
 int count;
 
-if (from_type[from_type_ptr] != FROM_MACRO) { error(15, US".endeach"); return; }
+if (from_type[from_type_ptr] != FROM_MACRO)
+  {
+  error(15, US".endeach");
+  return;
+  }
 
 count = (*p == 0)? 1 : readnumber(p);
 if (count < 0) return;
@@ -237,13 +245,13 @@ if (macro_argbase == NULL) macro_starteach = NULL;
 
 
 
-
 /*************************************************
 *           Handle .endinliteral                 *
 *************************************************/
 
 /* We only hit this as a stand-alone directive when in a literal section and
-the previous lines have been obeyed. There is nothing to do.
+the previous lines have been obeyed. There is nothing to do, but check for
+errors.
 
 Argument:   the rest of the line
 Returns:    nothing
@@ -252,8 +260,8 @@ Returns:    nothing
 static void
 do_endinliteral(uschar *p)
 {
-if (from_type[from_type_ptr] != FROM_MACRO) { error(15, US".endinliteral"); return; }
-if (*p != 0) error(19, ".endinliteral", p, 8, spaces, Ustrlen(p), circumflexes);
+if (from_type[from_type_ptr] != FROM_MACRO) error(15, US".endinliteral");
+else if (*p != 0) error(19, ".endinliteral", p, 8, spaces, Ustrlen(p), circumflexes);
 }
 
 
@@ -347,6 +355,7 @@ f->next = *ff;
 }
 
 
+
 /*************************************************
 *               Handle .include                  *
 *************************************************/
@@ -396,7 +405,11 @@ static void
 do_inliteral(uschar *p)
 {
 int state = -1;
-if (from_type[from_type_ptr] != FROM_MACRO) { error(15, US".inliteral"); return; }
+if (from_type[from_type_ptr] != FROM_MACRO)
+  {
+  error(15, US".inliteral");
+  return;
+  }
 if (Ustrcmp(p, "layout") == 0) state = LITERAL_LAYOUT;
 else if (Ustrcmp(p, "text") == 0) state = LITERAL_TEXT;
 else if (Ustrcmp(p, "off") == 0) state = LITERAL_OFF;
@@ -407,7 +420,6 @@ if (literal_state != state) skipto(US"inliteral", US".endinliteral");
 
 
 
-
 /*************************************************
 *                Handle .literal                 *
 *************************************************/
@@ -428,6 +440,7 @@ else error(5, p);
 }
 
 
+
 /*************************************************
 *               Handle .macro                    *
 *************************************************/
@@ -539,7 +552,6 @@ else error(26, p);
 
 
 
-
 /*************************************************
 *               Handle .nonl                     *
 *************************************************/
@@ -563,6 +575,7 @@ next_line = nonlbuffer;
 }
 
 
+
 /*************************************************
 *               Handle .pop                      *
 *************************************************/
@@ -660,7 +673,6 @@ pushed = ps;
 
 
 
-
 /*************************************************
 *                 Handle .revision               *
 *************************************************/
@@ -690,7 +702,6 @@ if (*p != 0 && Ustrcmp(p, "off") != 0)
 
 
 
-
 /*************************************************
 *               Handle .set                      *
 *************************************************/
@@ -769,6 +780,7 @@ static dirstr dirs[] = {
 static int cmdcount = sizeof(dirs)/sizeof(dirstr);
 
 
+
 /*************************************************
 *         Process a line starting with a dot     *
 *************************************************/
@@ -792,7 +804,6 @@ int top, bot, length;
 thisdir = p;  /* Save for error messages */
 
 misc_detrail(p);
-
 if (p[1] == 0 || isspace(p[1])) return;       /* Comment */
 
 /* Seek a built-in directive by binary chop. */
